==> 2.5.0.zip: cloudlog/application/language/russian/account_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['account_logbook_fields'] = 'Столбцы журнала';
$lang['account_column1_text'] = 'Выберите столбец 1';
$lang['account_column2_text'] = 'Выберите столбец 2';
$lang['account_column3_text'] = 'Выберите столбец 3';
$lang['account_column4_text'] = 'Выберите столбец 4';
$lang['account_column5_text'] = 'Выберите столбец 5 (только для журнала)';

$lang['account_create_user_account'] = ' Создать аккаунт пользователя';
$lang['account_edit_account'] = 'Редактировать аккаунт';

$lang['account_account_information'] = 'Информация об аккаунте';
$lang['account_user'] = "User";
$lang['account_word_edited'] = "edited";
$lang['account_username'] = 'Имя пользователя';
$lang['account_email_address'] = 'Адрес электронной почты';
$lang['account_password'] = 'Пароль';

$lang['account_roles'] = 'Роли';
$lang['account_user_role'] = 'Роль пользователя';
$lang['account_word_admin'] = 'Admin';

$lang['account_theme'] = 'Тема оформления';
$lang['account_stylesheet'] = 'Шаблон';

$lang['account_personal_information'] = 'Персональная информация';
$lang['account_first_name'] = 'Имя';
$lang['account_last_name'] = 'Фамилия';
$lang['account_callsign'] = 'Позывной';
$lang['account_gridsquare'] = 'QTH локатор';

$lang['account_cloudlog_preferences'] = 'Настройки Cloudlog';
$lang['account_timezone'] = 'Часовой пояс';
$lang['account_date_format'] = 'Формат даты';
$lang['account_log_end_time'] = 'Log End Times for QSOs Separately';
$lang['account_log_end_time_hint'] = 'Choose yes here if you want to log QSO start and end times separately. If set to \'No\' the end time will be the same as start time.';
$lang['account_measurement_preferences'] = 'Единицы измерения';
$lang['account_select_how_you_would_like_dates_shown_when_logged_into_your_account'] = 'Выберите представление даты для отображения в вашем аккаунте.';
$lang['account_choose_which_unit_distances_will_be_shown_in'] = 'Выберите единицы измерения расстояния';
$lang['account_cloudlog_language'] = 'Cloudlog Language';
$lang['account_choose_cloudlog_language'] = 'Choose Cloudlog language.';

$lang['account_main_menu'] = 'Главное меню';
$lang['account_show_notes_in_the_main_menu'] = 'Показывать заметки в главном меню.';

$lang['account_gridsquare_and_location_autocomplete'] = 'Автозаполнение QTH локатора и местоположения';
$lang['account_location_auto_lookup'] = 'Автозаполнение по местоположению.';
$lang['account_if_set_gridsquare_is_fetched_based_on_location_name'] = 'Если включено, QTH локатор будет определён на основе имени местоположения.';
$lang['account_sota_auto_lookup_gridsquare_and_name_for_summit'] = 'Автозаполнение QTH локатора и названия саммита по SOTA';
$lang['account_wwff_auto_lookup_gridsquare_and_name_for_reference'] = 'Автозаполнение QTH локатора и названия референции по WWFF';
$lang['account_pota_auto_lookup_gridsquare_and_name_for_park'] = 'Автозаполнение QTH локатора и названия парка по POTA';
$lang['account_if_set_name_and_gridsquare_is_fetched_from_the_api_and_filled_in_location_and_locator'] = 'Если включено, называние и квадрат запрашиваются по API и заполняются в поля местоположение и QTH локатор.';

$lang['account_previous_qsl_type'] = 'Тип предыдущего QSL';
$lang['account_select_the_type_of_qsl_to_show_in_the_previous_qsos_section'] = 'Выберите тип QSL для отобрашения в секции предыдущих QSO.';

$lang['account_qrzcom_hamqthcom_images'] = 'Изображения с qrz.com/hamqth.com';
$lang['account_show_profile_picture_of_qso_partner_from_qrzcom_hamqthcom_profile_in_the_log_qso_section'] = 'Показать изображение профиля партнера по QSO из его профиля на qrz.com/hamqth.com в разделе QSO журнала.';
$lang['account_please_set_your_qrzcom_hamqthcom_credentials_in_the_general_config_file'] = 'Пожалуйста, укажите свои учетные данные для qrz.com/hamqth.com в общем файле конфигурации.';

$lang['account_amsat_status_upload'] = 'Загрузка статуса AMSAT';
$lang['account_upload_status_of_sat_qsos_to'] = 'Загружать статус QSO через спутники в';

$lang['account_logbook_of_the_world'] = 'Logbook of the World';
$lang['account_logbook_of_the_world_lotw_username'] = 'Логин';
$lang['account_logbook_of_the_world_lotw_password'] = 'Пароль';
$lang['account_leave_blank_to_keep_existing_password'] = 'Оставьте пустым для сохранения текущего пароля';

$lang['account_clublog'] = 'Club Log';
$lang['account_clublog_email_callsign'] = 'Емэйл/позывной';
$lang['account_clublog_password'] = 'Пароль';
$lang['account_the_email_or_callsign_you_use_to_login_to_club_log'] = 'Емэйл или позывной, которые вы используете для логина в Club Log';

$lang['account_eqsl'] = 'eQSL';
$lang['account_eqslcc_username'] = 'Логин';
$lang['account_eqslcc_password'] = 'Пароль';

$lang['account_save_account_changes'] = 'Сохранить изменения';
$lang['account_create_account'] = 'Создать аккаунт';

$lang['account_delete_user_account'] = 'Удалить аккаунт пользователя';
$lang['account_are_you_sure_you_want_to_delete_the_user_account'] = 'Вы уверены в том, что вы хотите удалить аккаунт пользователя';
$lang['account_yes_delete_this_user'] = 'Да, удалить этого пользователя';
$lang['account_no_do_not_delete_this_user'] = 'Нет, не удалять этого пользователя';

$lang['account_forgot_password'] = 'Забыли пароль?';
$lang['account_you_can_reset_your_password_here'] = 'Вы можете сбросить свой пароль здесь.';
$lang['account_reset_password'] = 'Сбросить пароль';
$lang['account_the_email_field_is_required'] = 'Заполните адрес электронной почты';
$lang['account_confirm_password'] = 'Подтвердить Пароль';

$lang['account_forgot_your_password'] = 'Забыли пароль?';

$lang['account_login_to_cloudlog'] = 'Вход в Cloudlog';
$lang['account_login'] = 'Вход';

$lang['account_mastodon'] = 'Сервер Mastodon';
$lang['account_user_mastodon'] = 'URL профиля пользователя Mastodon';
$lang['account_user_mastodon_hint'] = "Main URL of your Mastodon server, e.g. <a href='https://radiosocial.de/' target='_blank'>https://radiosocial.de";

$lang['account_default_band_settings'] = 'Settings for Default Band and Confirmation';
$lang['account_gridmap_default_band'] = 'Диапазон по умолчанию';
$lang['account_qsl_settings'] = 'Default QSL-Methods';

$lang['account_winkeyer'] = 'Winkeyer';
$lang['account_winkeyer_hint'] = "Winkeyer support in Cloudlog is very experimental read the wiki first at <a href='https://github.com/magicbug/Cloudlog/wiki/Winkey' target='_blank'>https://github.com/magicbug/Cloudlog/wiki/Winkey</a> before enabling.";
$lang['account_winkeyer_enabled'] = "Winkeyer Features Enabled";

==> 2.6.6.zip: cloudlog/application/language/russian/account_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['account_logbook_fields'] = 'Столбцы журнала';
$lang['account_column1_text'] = 'Выберите столбец 1';
$lang['account_column2_text'] = 'Выберите столбец 2';
$lang['account_column3_text'] = 'Выберите столбец 3';
$lang['account_column4_text'] = 'Выберите столбец 4';
$lang['account_column5_text'] = 'Выберите столбец 5 (только для журнала)';

$lang['account_create_user_account'] = ' Создать аккаунт пользователя';
$lang['account_edit_account'] = 'Редактировать аккаунт';

$lang['account_account_information'] = 'Информация об аккаунте';
$lang['account_user'] = "User";
$lang['account_word_edited'] = "edited";
$lang['account_username'] = 'Имя пользователя';
$lang['account_email_address'] = 'Адрес электронной почты';
$lang['account_password'] = 'Пароль';

$lang['account_roles'] = 'Роли';
$lang['account_user_role'] = 'Роль пользователя';
$lang['account_word_admin'] = 'Admin';

$lang['account_theme'] = 'Тема оформления';
$lang['account_stylesheet'] = 'Шаблон';

$lang['account_personal_information'] = 'Персональная информация';
$lang['account_first_name'] = 'Имя';
$lang['account_last_name'] = 'Фамилия';

$lang['account_hamradio_information'] = "Ham Radio";
$lang['account_callsign'] = 'Позывной';
$lang['account_gridsquare'] = 'QTH локатор';

$lang['account_cloudlog_preferences'] = 'Настройки Cloudlog';
$lang['account_timezone'] = 'Часовой пояс';
$lang['account_date_format'] = 'Формат даты';
$lang['account_log_end_time'] = 'Записывать время завершения QSO отдельно';
$lang['account_log_end_time_hint'] = 'Отметьте, если вы хотите записывать время начала и завершения QSO раздельно. Если будет выбрано \'Нет\' то время завершения QSO будет совпадать с временм начала.';
$lang['account_quicklog_feature'] = "Быстрая запись";
$lang['account_quicklog_feature_hint'] = "С этой функцией вы можете записывать позывные, используя строку поиска в заголовке.";
$lang['account_quicklog_enter'] = "Быстрая запись - действие по нажатию Ввод";
$lang['account_quicklog_enter_hint'] = "Какое действие должно выполняться при нажатии Ввод в поле быстрой записи?";
$lang['account_quicklog_enter_log'] = "Запись позывного в журнал";
$lang['account_quicklog_enter_search'] = "Поиск позывного";
$lang['account_measurement_preferences'] = 'Единицы измерения';
$lang['account_select_how_you_would_like_dates_shown_when_logged_into_your_account'] = 'Выберите представление даты для отображения в вашем аккаунте.';
$lang['account_choose_which_unit_distances_will_be_shown_in'] = 'Выберите единицы измерения расстояния';
$lang['account_cloudlog_language'] = 'Язык Cloudlog';
$lang['account_choose_cloudlog_language'] = 'Выберите язык Cloudlog.';

$lang['account_main_menu'] = 'Главное меню';
$lang['account_show_notes_in_the_main_menu'] = 'Показывать заметки в главном меню.';

$lang['account_gridsquare_and_location_autocomplete'] = 'Автозаполнение QTH локатора и местоположения';
$lang['account_location_auto_lookup'] = 'Автозаполнение по местоположению.';
$lang['account_if_set_gridsquare_is_fetched_based_on_location_name'] = 'Если включено, QTH локатор будет определён на основе имени местоположения.';
$lang['account_sota_auto_lookup_gridsquare_and_name_for_summit'] = 'Автозаполнение QTH локатора и названия саммита по SOTA';
$lang['account_wwff_auto_lookup_gridsquare_and_name_for_reference'] = 'Автозаполнение QTH локатора и названия референции по WWFF';
$lang['account_pota_auto_lookup_gridsquare_and_name_for_park'] = 'Автозаполнение QTH локатора и названия парка по POTA';
$lang['account_if_set_name_and_gridsquare_is_fetched_from_the_api_and_filled_in_location_and_locator'] = 'Если включено, называние и квадрат запрашиваются по API и заполняются в поля местоположение и QTH локатор.';

$lang['account_previous_qsl_type'] = 'Тип предыдущего QSL';
$lang['account_select_the_type_of_qsl_to_show_in_the_previous_qsos_section'] = 'Выберите тип QSL для отобрашения в секции предыдущих QSO.';

$lang['account_qrzcom_hamqthcom_images'] = 'Изображения с qrz.com/hamqth.com';
$lang['account_show_profile_picture_of_qso_partner_from_qrzcom_hamqthcom_profile_in_the_log_qso_section'] = 'Показать изображение профиля партнера по QSO из его профиля на qrz.com/hamqth.com в разделе QSO журнала.';
$lang['account_please_set_your_qrzcom_hamqthcom_credentials_in_the_general_config_file'] = 'Пожалуйста, укажите свои учетные данные для qrz.com/hamqth.com в общем файле конфигурации.';

$lang['account_amsat_status_upload'] = 'Загрузка статуса AMSAT';
$lang['account_upload_status_of_sat_qsos_to'] = 'Загружать статус QSO через спутники в';

$lang['account_logbook_of_the_world'] = 'Logbook of the World';
$lang['account_logbook_of_the_world_lotw_username'] = 'Логин';
$lang['account_logbook_of_the_world_lotw_password'] = 'Пароль';
$lang['account_leave_blank_to_keep_existing_password'] = 'Оставьте пустым для сохранения текущего пароля';

$lang['account_clublog'] = 'Clublog';
$lang['account_clublog_email_callsign'] = 'Емэйл/позывной';
$lang['account_clublog_password'] = 'Пароль';
$lang['account_the_email_or_callsign_you_use_to_login_to_club_log'] = 'Емэйл или позывной, которые вы используете для логина в Clublog';

$lang['account_eqsl'] = 'eQSL';
$lang['account_eqslcc_username'] = 'Логин';
$lang['account_eqslcc_password'] = 'Пароль';

$lang['account_save_account_changes'] = 'Сохранить изменения';
$lang['account_create_account'] = 'Создать аккаунт';

$lang['account_delete_user_account'] = 'Удалить аккаунт пользователя';
$lang['account_are_you_sure_you_want_to_delete_the_user_account'] = 'Вы уверены в том, что вы хотите удалить аккаунт пользователя';
$lang['account_yes_delete_this_user'] = 'Да, удалить этого пользователя';
$lang['account_no_do_not_delete_this_user'] = 'Нет, не удалять этого пользователя';

$lang['account_forgot_password'] = 'Забыли пароль?';
$lang['account_you_can_reset_your_password_here'] = 'Вы можете сбросить свой пароль здесь.';
$lang['account_reset_password'] = 'Сбросить пароль';
$lang['account_the_email_field_is_required'] = 'Заполните адрес электронной почты';
$lang['account_confirm_password'] = 'Подтвердить Пароль';

$lang['account_forgot_your_password'] = 'Забыли пароль?';

$lang['account_login_to_cloudlog'] = 'Вход в Cloudlog';
$lang['account_login'] = 'Вход';

$lang['account_mastodon'] = 'Сервер Mastodon';
$lang['account_user_mastodon'] = 'URL профиля пользователя Mastodon';
$lang['account_user_mastodon_hint'] = "Главный URL вашего сервера Mastodon, к примеру, <a href='https://radiosocial.de/' target='_blank'>https://radiosocial.de";

$lang['account_default_band_settings'] = 'Настройки для диапазона и способ подтверждения (QSL) по умолчанию';
$lang['account_gridmap_default_band'] = 'Диапазон по умолчанию';
$lang['account_qsl_settings'] = 'Способы подтверждения (QSL) по умолчанию';

$lang['account_winkeyer'] = 'Winkeyer';
$lang['account_winkeyer_hint'] = "Поддержка Winkeyer в Cloudlog в стадии эксперимента, прочитайте сначала вики (<a href='https://github.com/magicbug/Cloudlog/wiki/Winkey' target='_blank'>https://github.com/magicbug/Cloudlog/wiki/Winkey</a>) перед включением.";
$lang['account_winkeyer_enabled'] = "Функционал Winkeyer включен";

$lang['account_map_params'] = "Настройки карты";
$lang['account_map_qso_by_default'] = "QSO (по умолчанию)";
$lang['account_map_qso_confirm'] = "QSO (подтверждённые)";
$lang['account_map_qso_confirm_same_qso'] = "(Если 'Нет', отображаются как ".$lang['account_map_qso_by_default'].")";

$lang['account_general_information'] = "Основные данные";
$lang['account_qso_logging_options'] = "Настройки записи QSO";
$lang['account_third_party_services'] = "Сторонние сервисы";
$lang['account_default_values'] = "Значения по умолчанию";
$lang['account_miscellaneous'] = "Разное";
